/*
 * Copyright (C) 2002-2007 The Warp Rogue Team
 * Part of the Warp Rogue Project
 *
 * This software is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License.
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY.
 *
 * See the license.txt file for more details.
 */

/*
 * Module Name: Career
 * Description: -
 */

#define Uses_Ui
#define Uses_Util
#define Uses_DataFile
#define Uses_ProgramManager
#define Uses_Object
#define Uses_Stats
#define Uses_Perks
#define Uses_Faction
#include "mheader.h"

#include "career.h"


#define N_CAREER_TYPES			2

#define CAREER_BOX_BUFFER_SIZE		50



static void		career_init(CAREER *);


/*
 * career type names
 */
static const char *	CareerTypeName[N_CAREER_TYPES] = {
			"Basic",
			"Advanced"
};


/*
 * the career box
 */
static CAREER  *	CareerBox = NULL;
static N_CAREERS	CareerBoxCurrentSize = 0;
static N_CAREERS	CareerBoxMaxSize = 0;






/*
 * career module clean up
 */
void career_clean_up(void)
{
	int i;

	if (CareerBox == NULL) return;

	for (i = 0; i < CareerBoxCurrentSize; i++) {

		list_destroy_with(CareerBox[i].trappings,
			object_destroy
		);
	}

	free(CareerBox);
}



/*
 * adds a career to the career box
 */
CAREER * career_box_new_career(void)
{
	CAREER *career;

	++CareerBoxCurrentSize;

	if (CareerBoxCurrentSize > CareerBoxMaxSize) {
		CareerBoxMaxSize += CAREER_BOX_BUFFER_SIZE;

		CareerBox = checked_realloc(CareerBox,
			CareerBoxMaxSize *
			sizeof *CareerBox
		);

	}

	career = &CareerBox[CareerBoxCurrentSize - 1];

	career->trappings = list_new();

	career_init(career);

	return career;
}



/*
 * optimizes the career box
 */
void career_box_optimize(void)
{
	if (CareerBoxCurrentSize < CareerBoxMaxSize) {
		CareerBoxMaxSize = CareerBoxCurrentSize;

		CareerBox = checked_realloc(CareerBox,
			CareerBoxMaxSize *
			sizeof *CareerBox
		);
	}

}



/*
 * returns a career pointer
 */
CAREER * get_career_pointer(CAREER_INDEX career_index)
{
	if (career_index == CAREER_NIL) return NULL;

	return &CareerBox[career_index];
}



/*
 * returns the number of available careers
 */
N_CAREERS get_n_careers(void)
{
	return CareerBoxCurrentSize;
}



/*
 * checks whether a character has completed his current career or not
 */
bool career_completed(const CHARACTER *character)
{
	int i;
	CAREER *career;

	career = get_career_pointer(character->career);

	for (i = 0; i < MAX_STATS; i++) {

		if (character->stat[i].advance <
			career->max_stat_advance[i]) {

			return false;
		}
	}

	return true;
}



/*
 * the "Career" screen
 */
void career_screen(const CAREER *career)
{
	command_bar_set(1, CM_EXIT);

	render_career_screen(career);

	update_screen();

	command_bar_get_command();
}



/*
 * returns the description of a career
 */
char * career_description(char *description, const CAREER *career)
{

	return data_file_career_description(description, career);
}



/*
 * name -> career index
 */
CAREER_INDEX name_to_career_index(const char *name)
{
	int i;

	for (i = 0; i < CareerBoxCurrentSize; i++) {

		if (STR_EQ(name, CareerBox[i].name)) {
			return i;
		}

	}

	die("*** CORE ERROR *** invalid career (%s)", name);

	return 0;
}



/*
 * returns the name of a career type
 */
const char * career_type_name(CAREER_TYPE career_type)
{
	return CareerTypeName[career_type];
}



/*
 * name -> career type
 */
CAREER_TYPE name_to_career_type(const char *name)
{
	int i;

	for (i = 0; i < N_CAREER_TYPES; i++) {

		if (STR_EQ(name, CareerTypeName[i])) {
			return i;
		}
	}

	die("*** CORE ERROR *** invalid career type (%s)", name);

	return 0;
}




/*
 * initializes a career data structure
 */
static void career_init(CAREER *career)
{
	int i;

	CLEAR_STRING(career->name);

	career->type = CAREER_TYPE_BASIC;
	career->color = C_DEFAULT;

	for (i = 0; i < MAX_PERKS; i++) {
		career->perk[i] = false;
	}

	for (i = 0; i < MAX_STATS; i++) {
		career->max_stat_advance[i] = 0;
	}

	for (i = 0; i < MAX_CAREER_EXITS; i++) {
		CLEAR_STRING(career->exit[i]);
	}

}


