#
# MinGW (pure MinGW i.e. no MSYS) development makefile 
#


SRC_LIB=\
  lib/dungeon.c \
  lib/llist.c \
  lib/path.c \
  lib/rdb.c \
  lib/rng.c

SRC_BACK_END=\
  sdl/be_sdl.c \
  windows/be_win.c

SRC_UI=\
  ui/ui_input.c \
  ui/ui_cmd.c \
  ui/ui_c_bar.c \
  ui/ui_commo.c \
  ui/ui_game.c \
  ui/ui_g_adv.c \
  ui/ui_info.c \
  ui/ui_misc.c \
  ui/ui_msg.c \
  ui/ui_visio.c \
  ui/ui_menu.c \
  ui/ui.c \
  ui/ui_color.c \
  ui/ui_keys.c 

SRC_MAIN=\
  actions.c \
  area.c \
  areatran.c \
  brain.c \
  career.c \
  charact.c \
  charadv.c \
  chargen.c \
  charstat.c \
  cmd.c \
  combat.c \
  combat_c.c \
  combat_r.c \
  datafile.c \
  death.c \
  debug.c \
  dice.c \
  drugs.c \
  dyn_msg.c \
  effect.c \
  equip.c \
  event.c \
  faction.c \
  game.c \
  grammar.c \
  help.c \
  hof.c \
  inv.c \
  log.c \
  loadsave.c \
  macro.c \
  manufact.c \
  movement.c \
  npc.c \
  object.c \
  options.c \
  party.c \
  pathfind.c \
  percept.c \
  perks.c \
  prgman.c \
  psychic.c \
  round.c \
  sector.c \
  talk.c \
  target.c \
  terrain.c \
  trade.c \
  util.c \
  world.c \
  worldgen.c

SRC=\
  $(SRC_LIB) \
  $(SRC_BACK_END) \
  $(SRC_UI) \
  $(SRC_MAIN) 


OBJ=$(SRC:.c=.o)
EXE=wrogue.exe
RES=wrogue.res

CC=gcc
CFLAGS=-Wall -Wextra -ansi -pedantic  -Wpointer-arith -Wstrict-prototypes \
 -Wmissing-prototypes -Wdeclaration-after-statement -Wshadow -Wmissing-declarations \
-Wold-style-definition -g -I. -I./lib -I./ui
LDFLAGS=-lmingw32 -lSDLmain -lSDL -lSDL_ttf -mwindows 
WINDRES=windres
RM=del

%.o: %.c
	@$(CC) $(CFLAGS) -o $@ -c $<

$(RES) : .\windows\wrogue.rc
	$(WINDRES) $< -O coff -o $@

$(EXE): $(OBJ) $(RES)
	$(CC) $(OBJ) $(RES) $(LDFLAGS) -o $@

.PHONY : all	
all: $(EXE)
			
.PHONY : install
install: all
	copy $(EXE) ..
	copy .\windows\readme.txt ..

.PHONY : clean
clean:
	-$(RM) *.o
	-$(RM) .\sdl\*.o
	-$(RM) .\lib\*.o
	-$(RM) .\ui\*.o
	-$(RM) .\windows\*.o
	-$(RM) *.res
	-$(RM) *.exe

