/*
 * Copyright (C) 2002-2007 The Warp Rogue Team
 * Part of the Warp Rogue Project
 *
 * This software is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License.
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY.
 *
 * See the license.txt file for more details.
 */

/*
 * UNIX back-end
 */

/*
 * Most of the needed back-end functionality is actually provided by
 * the cross-platform SDL back-end
 */

#include <sys/types.h>
#include <sys/stat.h>
#include <unistd.h>
#include <errno.h>
#include <fcntl.h>

#define Uses_ProgramManager
#define Uses_Util
#define Uses_Game
#include "mheader.h"


static char *		user_data_path(char *, PROGRAM_DIRECTORY, 
				const char *
			);


static const char *	ProgramDirectory[MAX_PROGRAM_DIRECTORIES] = {
	
	"/.wrogue/",
	"./data/",
	"./data/config/",
	"./data/graphics/",
	"./data/terrain/",
	"./data/objects/",
	"./data/charact/",
	"./data/text/"

};



/*
 * returns the path of a file
 */
char * data_path(char *path, PROGRAM_DIRECTORY directory, const char *filename)
{

	if (directory == DIR_USER_DATA) {

		return user_data_path(path, directory, filename);
	}

	strcpy(path, ProgramDirectory[directory]);
	strcat(path, filename);

	return path;
}



/*
 * main
 */
int main(int argc, char *argv[])
{
	NOT_USED(argc);
	NOT_USED(argv);

	run_game();

	return EXIT_SUCCESS;
}



/*
 * user data path - data_path() auxiliary function
 */
static char * user_data_path(char *path, PROGRAM_DIRECTORY directory, 
	const char *filename
)
{
	char *home;
	struct stat sb;

	home = getenv("HOME");

	if (home == NULL) {

		die_no_data_path("*** BE_UNIX ERROR *** " \
			"no HOME environment variable set"
		);

		return NULL;
	}

	strcpy(path, home);
	strcat(path, ProgramDirectory[directory]);

	if(stat(path, &sb) == 0) {

		strcat(path, filename);

		return path;
	}

	if (errno != ENOENT) {

		die_no_data_path("*** BE_UNIX ERROR *** " \
			"could not access '%s': %s",
			path, strerror(errno)
		);

		return NULL;
	}

	if(mkdir(path, S_IRUSR | S_IWUSR | S_IXUSR) != 0) {

		die_no_data_path("*** BE_UNIX ERROR *** " \
			"could not create directory '%s': %s",
			path, strerror(errno)
		);

		return NULL;
	}

	strcat(path, filename);

	return path;
}

